/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlabstracturlinterceptor.sip"
#include <qqmlabstracturlinterceptor.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 165 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlincubator.sip"
#include <qqmlincubator.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlproperty.sip"
#include <qqmlproperty.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsengine.sip"
#include <qjsengine.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsvalue.sip"
#include <qjsvalue.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsmanagedvalue.sip"
#include <qjsmanagedvalue.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlapplicationengine.sip"
#include <qqmlapplicationengine.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlcomponent.sip"
#include <qqmlcomponent.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlerror.sip"
#include <qqmlerror.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlexpression.sip"
#include <qqmlexpression.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 40 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlextensionplugin.sip"
#include <qqmlextensionplugin.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlincubator.sip"
#include <qqmlincubator.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmllist.sip"
#include <qqmllist.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlpropertymap.sip"
#include <qqmlpropertymap.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlscriptstring.sip"
#include <qqmlscriptstring.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtQml[] = {
    'm', 'a', 'r', 'k', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'A', 's', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 0,
    'Q', 'Q', 'm', 'l', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'U', 'r', 'l', 'I', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', ':', ':', 'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'Q', 'm', 'l', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 'B', 'a', 's', 'e', ':', ':', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'J', 'S', 'V', 'a', 'l', 'u', 'e', ':', ':', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'Q', 'm', 'l', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'U', 'r', 'l', 'I', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', '*', '>', 0,
    'Q', 'Q', 'm', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'y', 'p', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'Q', 'm', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'P', 'a', 'i', 'r', '>', 0,
    'Q', 'Q', 'm', 'l', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 'B', 'a', 's', 'e', ':', ':', 'I', 'm', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'U', 'n', 'c', 'r', 'e', 'a', 't', 'a', 'b', 'l', 'e', 'M', 'e', 't', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'W', 'a', 'r', 'n', 'i', 'n', 'g', 's', 'T', 'o', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'Q', 'm', 'l', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'Q', 'Q', 'm', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', ':', ':', 'C', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'F', 'i', 'l', 'e', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'F', 'o', 'r', 'c', 'e', 'A', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 'I', 'm', 'a', 'g', 'e', 'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'Q', 'm', 'l', 'I', 'n', 'c', 'u', 'b', 'a', 't', 'o', 'r', ':', ':', 'I', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'o', 'u', 't', 'p', 'u', 't', 'W', 'a', 'r', 'n', 'i', 'n', 'g', 's', 'T', 'o', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'J', 'S', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', '>', 0,
    'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'n', 'g', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'S', 'i', 'n', 'g', 'l', 'e', 't', 'o', 'n', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'Q', 'Q', 'm', 'l', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 'B', 'a', 's', 'e', ':', ':', 'F', 'l', 'a', 'g', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'W', 'i', 't', 'h', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'q', 'm', 'l', 'A', 't', 't', 'a', 'c', 'h', 'e', 'd', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'T', 'y', 'p', 'e', 'N', 'o', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'G', 'a', 'r', 'b', 'a', 'g', 'e', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'J', 'S', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'O', 'b', 'j', 'e', 'c', 't', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'Q', 'Q', 'm', 'l', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'U', 'r', 'l', 'I', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'U', 'n', 'c', 'r', 'e', 'a', 't', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'Q', 'm', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'P', 'a', 'i', 'r', 0,
    'Q', 'Q', 'm', 'l', 'E', 'n', 'g', 'i', 'n', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'Q', 'Q', 'm', 'l', 'L', 'i', 's', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', '<', 'Q', 'O', 'b', 'j', 'e', 'c', 't', '>', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'm', 'l', 'C', 'l', 'e', 'a', 'r', 'T', 'y', 'p', 'e', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'Q', 'm', 'l', 'I', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'A', 'n', 'o', 'n', 'y', 'm', 'o', 'u', 's', 'T', 'y', 'p', 'e', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'S', 'i', 'n', 'g', 'l', 'e', 't', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'P', 'y', 'Q', 't', '6', '.', 's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'J', 'S', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'V', 'a', 'l', 'u', 'e', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'Q', 'm', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'I', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    's', 'e', 't', 'N', 'o', 't', 'i', 'f', 'y', 'O', 'n', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'J', 'S', 'V', 'a', 'l', 'u', 'e', ':', ':', 'S', 'p', 'e', 'c', 'i', 'a', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'f', 'i', 'n', 'd', 'O', 'b', 'j', 'e', 'c', 't', 's', 'R', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 'l', 'y', 0,
    'Q', 'J', 'S', 'M', 'a', 'n', 'a', 'g', 'e', 'd', 'V', 'a', 'l', 'u', 'e', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'J', 'S', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'Q', 'Q', 'm', 'l', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'Q', 'm', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'Q', 'm', 'l', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 'B', 'a', 's', 'e', 0,
    'Q', 'Q', 'm', 'l', 'I', 'n', 'c', 'u', 'b', 'a', 't', 'o', 'r', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'f', 'i', 'n', 'd', 'O', 'b', 'j', 'e', 'c', 't', 'R', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 'l', 'y', 0,
    'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'n', 'g', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'E', 'x', 't', 'r', 'a', 'F', 'i', 'l', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 's', 0,
    's', 'e', 't', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 0,
    'A', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 'I', 'f', 'N', 'e', 's', 't', 'e', 'd', 0,
    'Q', 'J', 'S', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'n', 'o', 't', 'i', 'f', 'y', 'O', 'n', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'y', 'p', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'U', 'r', 'l', 'I', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    's', 'e', 't', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'J', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'Q', 'J', 'S', 'V', 'a', 'l', 'u', 'e', ':', ':', 'E', 'r', 'r', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'Q', 'm', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'Q', 'm', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', '>', 0,
    'Q', 'Q', 'm', 'l', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'C', 'a', 'c', 'h', 'e', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'S', 't', 'a', 'c', 'k', 'T', 'r', 'a', 'c', 'e', 0,
    'i', 's', 'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'R', 'e', 'v', 'i', 's', 'i', 'o', 'n', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'F', 'o', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    't', 'o', 'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'Q', 'Q', 'm', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', ':', ':', 'T', 'y', 'p', 'e', 0,
    'a', 't', 't', 'a', 'c', 'h', 'e', 'd', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'i', 's', 'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 'L', 'i', 't', 'e', 'r', 'a', 'l', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    't', 'r', 'i', 'm', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'C', 'a', 'c', 'h', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 0,
    'Q', 'J', 'S', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 'Q', 'm', 'l', 'L', 'i', 's', 't', 'R', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'a', 'd', 'd', 'U', 'r', 'l', 'I', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', 0,
    'c', 'a', 'l', 'l', 'A', 's', 'C', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'o', 'r', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 0,
    'i', 'n', 's', 't', 'a', 'l', 'l', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'n', 'e', 'e', 'd', 's', 'N', 'o', 't', 'i', 'f', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'M', 'o', 'd', 'u', 'l', 'e', 0,
    's', 'e', 't', 'E', 'x', 't', 'r', 'a', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 's', 0,
    's', 'e', 't', 'I', 'm', 'p', 'o', 'r', 't', 'P', 'a', 't', 'h', 'L', 'i', 's', 't', 0,
    's', 'e', 't', 'P', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 'L', 'i', 's', 't', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    's', 'i', 'n', 'g', 'l', 'e', 't', 'o', 'n', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'u', 'i', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'n', 's', 'o', 'l', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'C', 'o', 'n', 'v', 'e', 'r', 't', 'J', 'S', 'O', 'b', 'j', 'e', 'c', 't', 's', 0,
    'Q', 'J', 'S', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'N', 'u', 'l', 'l', 0,
    'Q', 'J', 'S', 'V', 'a', 'l', 'u', 'e', 'I', 't', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'Q', 'm', 'l', 'E', 'r', 'r', 'o', 'r', '>', 0,
    'Q', 'Q', 'm', 'l', 'F', 'i', 'l', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 0,
    'Q', 'Q', 'm', 'l', 'P', 'a', 'r', 's', 'e', 'r', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'Q', 'm', 'l', 'S', 'c', 'r', 'i', 'p', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'a', 'd', 'd', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'c', 'a', 'l', 'l', 'W', 'i', 't', 'h', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'F', 'o', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'i', 's', 'S', 'i', 'g', 'n', 'a', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'M', 'e', 't', 'a', 'T', 'y', 'p', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 0,
    'q', 'm', 'l', 'P', 'r', 'o', 't', 'e', 'c', 't', 'M', 'o', 'd', 'u', 'l', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    't', 'o', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 'I', 's', 'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'Q', 'J', 'S', 'M', 'a', 'n', 'a', 'g', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'J', 'S', 'V', 'a', 'l', 'u', 'e', '>', 0,
    'Q', 'Q', 'm', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'M', 'a', 'p', 0,
    'R', 'e', 't', 'a', 'i', 'n', 'J', 'S', 'O', 'b', 'j', 'e', 'c', 't', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 'i', 'n', 'g', 'l', 'e', 't', 'o', 'n', 's', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'f', 'o', 'r', 'c', 'e', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'N', 'o', 't', 'i', 'f', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'l', 'i', 's', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'm', 'l', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'S', 't', 'a', 't', 'e', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'T', 'y', 'p', 'e', 's', 0,
    'u', 'r', 'l', 'I', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', 's', 0,
    'J', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'F', 'i', 'l', 'e', 0,
    'Q', 'Q', 'm', 'l', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'R', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'b', 'o', 'o', 'l', 'e', 'a', 'n', 'L', 'i', 't', 'e', 'r', 'a', 'l', 0,
    'c', 'o', 'l', 'l', 'e', 'c', 't', 'G', 'a', 'r', 'b', 'a', 'g', 'e', 0,
    'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'C', 'r', 'e', 'a', 't', 'e', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'h', 'a', 's', 'O', 'w', 'n', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 'm', 'p', 'o', 'r', 't', 'P', 'a', 't', 'h', 'L', 'i', 's', 't', 0,
    'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'l', 'o', 'a', 'd', 'F', 'r', 'o', 'm', 'M', 'o', 'd', 'u', 'l', 'e', 0,
    'n', 'e', 'w', 'E', 'r', 'r', 'o', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'n', 'e', 'w', 'Q', 'M', 'e', 't', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 'L', 'i', 's', 't', 0,
    'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'M', 'o', 'd', 'u', 'l', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'e', 'd', 0,
    's', 'e', 't', 'M', 'e', 's', 's', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    's', 't', 'r', 'i', 'c', 't', 'l', 'y', 'E', 'q', 'u', 'a', 'l', 's', 0,
    't', 'o', 'M', 'a', 'n', 'a', 'g', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'A', 'l', 'l', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'I', 'm', 'a', 'g', 'e', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 0,
    'Q', 'Q', 'm', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'Q', 'Q', 'm', 'l', 'I', 'n', 'c', 'u', 'b', 'a', 't', 'o', 'r', 0,
    'a', 'd', 'd', 'I', 'm', 'p', 'o', 'r', 't', 'P', 'a', 't', 'h', 0,
    'a', 'd', 'd', 'P', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 0,
    'c', 'a', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 'L', 'a', 's', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'C', 'o', 'n', 't', 'e', 'x', 't', 's', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'i', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'i', 's', 'I', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'e', 'd', 0,
    'i', 's', 'M', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'N', 'u', 'l', 'l', 'L', 'i', 't', 'e', 'r', 'a', 'l', 0,
    'i', 's', 'Q', 'M', 'e', 't', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'n', 'a', 'm', 'e', 'F', 'o', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'L', 'i', 't', 'e', 'r', 'a', 'l', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'F', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'U', 'i', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'r', 'i', 'n', 'g', 'L', 'i', 't', 'e', 'r', 'a', 'l', 0,
    't', 'o', 'Q', 'M', 'e', 't', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    't', 'o', 'S', 'c', 'r', 'i', 'p', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'A', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 0,
    'C', 'p', 'p', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'G', 'e', 'n', 'e', 'r', 'i', 'c', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'Q', 'm', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'i', 'm', 'p', 'o', 'r', 't', 'M', 'o', 'd', 'u', 'l', 'e', 0,
    'i', 'm', 'p', 'o', 'r', 't', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'U', 'r', 'l', 0,
    'i', 's', 'D', 'e', 's', 'i', 'g', 'n', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'R', 'e', 's', 'e', 't', 't', 'a', 'b', 'l', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'P', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'P', 'y', 'Q', 't', '6', '.', 'Q', 't', 'Q', 'm', 'l', 0,
    'Q', 'Q', 'm', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'S', 'y', 'n', 't', 'a', 'x', 'E', 'r', 'r', 'o', 'r', 0,
    '_', '_', 'g', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 't', 'r', 'u', 'e', 'd', 'i', 'v', '_', '_', 0,
    'b', 'e', 'g', 'i', 'n', 'C', 'r', 'e', 'a', 't', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'h', 'a', 's', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 'n', 'c', 'u', 'b', 'a', 't', 'e', 'F', 'o', 'r', 0,
    'i', 's', 'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'm', 'e', 's', 's', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 's', 'o', 'l', 'v', 'e', 'd', 'U', 'r', 'l', 0,
    'r', 'e', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'r', 'o', 'o', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'r', 'o', 'o', 't', 'O', 'b', 'j', 'e', 'c', 't', 's', 0,
    's', 'c', 'o', 'p', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 0,
    't', 'o', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 'Q', 'm', 'l', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'm', 'l', 'd', 'i', 'r', 'F', 'i', 'l', 'e', 0,
    'R', 'a', 'n', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    '_', '_', 'r', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    'c', 'a', 'n', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'c', 'a', 't', 'c', 'h', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'a', 's', 's', 'B', 'e', 'g', 'i', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'f', 'o', 'r', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'i', 's', 'B', 'i', 'n', 'd', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'C', 'a', 'l', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'i', 's', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'W', 'r', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'l', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'n', 'e', 'w', 'Q', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'q', 'm', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'L', 'a', 's', 't', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'U', 'r', 'l', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    't', 'h', 'r', 'o', 'w', 'E', 'r', 'r', 'o', 'r', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 0,
    'u', 'i', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'E', 'v', 'a', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'u', 'l', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 'J', 'S', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'Q', 'm', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'y', 'p', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'r', 'l', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', 0,
    'c', 'a', 'n', 'A', 'p', 'p', 'e', 'n', 'd', 0,
    'e', 'r', 'r', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 0,
    'i', 's', 'B', 'o', 'o', 'l', 'e', 'a', 'n', 0,
    'i', 's', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'i', 's', 'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'i', 's', 'Q', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'i', 's', 'V', 'a', 'r', 'i', 'a', 'n', 't', 0,
    'n', 'e', 'w', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'n', 'e', 'w', 'S', 'y', 'm', 'b', 'o', 'l', 0,
    'p', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 0,
    'q', 'j', 's', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'q', 'm', 'l', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'q', 'm', 'l', 'T', 'y', 'p', 'e', 'I', 'd', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'T', 'a', 'r', 'g', 'e', 't', 0,
    't', 'o', 'B', 'o', 'o', 'l', 'e', 'a', 'n', 0,
    't', 'o', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    't', 'o', 'J', 'S', 'V', 'a', 'l', 'u', 'e', 0,
    't', 'o', 'Q', 'O', 'b', 'j', 'e', 'c', 't', 0,
    't', 'o', 'V', 'a', 'r', 'i', 'a', 'n', 't', 0,
    'Q', 'J', 'S', 'V', 'a', 'l', 'u', 'e', 0,
    'U', 'R', 'I', 'E', 'r', 'r', 'o', 'r', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    'c', 'a', 'n', 'C', 'l', 'e', 'a', 'r', 0,
    'c', 'a', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'h', 'a', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 's', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'i', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'i', 's', 'R', 'e', 'g', 'E', 'x', 'p', 0,
    'i', 's', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'i', 's', 'S', 'y', 'm', 'b', 'o', 'l', 0,
    'l', 'o', 'a', 'd', 'D', 'a', 't', 'a', 0,
    'm', 'e', 't', 'a', 'T', 'y', 'p', 'e', 0,
    'n', 'e', 'w', 'A', 'r', 'r', 'a', 'y', 0,
    'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 'l', 'e', 'c', 't', 'o', 'r', 0,
    't', 'o', 'D', 'o', 'u', 'b', 'l', 'e', 0,
    't', 'o', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    't', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'w', 'a', 'r', 'n', 'i', 'n', 'g', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 0,
    'Q', 'm', 'l', 'F', 'i', 'l', 'e', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    '_', '_', 'a', 'd', 'd', '_', '_', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    '_', '_', 'm', 'o', 'd', '_', '_', 0,
    '_', '_', 'm', 'u', 'l', '_', '_', 0,
    '_', '_', 'n', 'e', 'g', '_', '_', 0,
    '_', '_', 'p', 'o', 's', '_', '_', 0,
    '_', '_', 's', 'u', 'b', '_', '_', 0,
    'b', 'a', 's', 'e', 'U', 'r', 'l', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 0,
    'h', 'a', 's', 'N', 'e', 'x', 't', 0,
    'i', 's', 'A', 'r', 'r', 'a', 'y', 0,
    'i', 's', 'B', 'o', 'u', 'n', 'd', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'y', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'l', 'o', 'a', 'd', 'U', 'r', 'l', 0,
    'm', 'e', 's', 's', 'a', 'g', 'e', 0,
    'q', 'm', 'l', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 0,
    'P', 'i', 'x', 'm', 'a', 'p', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'g', 'e', '_', '_', 0,
    '_', '_', 'g', 't', '_', '_', 0,
    '_', '_', 'l', 'e', '_', '_', 0,
    '_', '_', 'l', 't', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 0,
    'c', 'r', 'e', 'a', 't', 'e', 0,
    'e', 'n', 'g', 'i', 'n', 'e', 0,
    'e', 'q', 'u', 'a', 'l', 's', 0,
    'e', 'r', 'r', 'o', 'r', 's', 0,
    'f', 'r', 'e', 'e', 'z', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'i', 's', 'B', 'o', 'o', 'l', 0,
    'i', 's', 'D', 'a', 't', 'e', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'm', 'e', 't', 'h', 'o', 'd', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'U', 'r', 'l', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    't', 'o', 'B', 'o', 'o', 'l', 0,
    't', 'o', 'U', 'I', 'n', 't', 0,
    'I', 'm', 'a', 'g', 'e', 0,
    'c', 'a', 'n', 'A', 't', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'i', 's', 'U', 'r', 'l', 0,
    'r', 'e', 's', 'e', 't', 0,
    's', 'c', 'o', 'p', 'e', 0,
    't', 'o', 'I', 'n', 't', 0,
    't', 'o', 'U', 'r', 'l', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'w', 'r', 'i', 't', 'e', 0,
    'a', 'r', 'g', 's', 0,
    'c', 'a', 'l', 'l', 0,
    'd', 'a', 't', 'a', 0,
    'e', 'x', 'i', 't', 0,
    'k', 'e', 'y', 's', 0,
    'l', 'i', 'n', 'e', 0,
    'l', 'o', 'a', 'd', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'n', 'e', 'x', 't', 0,
    'q', 'u', 'i', 't', 0,
    'r', 'e', 'a', 'd', 0,
    's', 'i', 'z', 'e', 0,
    's', 'w', 'a', 'p', 0,
    'u', 'r', 'l', 0,
    'a', 't', 0,
};
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqml.sip"
#include <qqml.h>
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsengine.sip"
#include <qjsengine.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlproperty.sip"
// Imports from QtCore.
pyqt6_qtqml_get_connection_parts_t pyqt6_qtqml_get_connection_parts;
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
// Imports from QtCore.
pyqt6_qtqml_get_qmetaobject_t pyqt6_qtqml_get_qmetaobject;
#line 529 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"

void sipVH_QtQml_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QQmlProperty& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QQmlProperty(a0), sipType_QQmlProperty, SIP_NULLPTR);
}

::QVariant sipVH_QtQml_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QVariant& a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QNetworkAccessManager* sipVH_QtQml_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0)
{
    ::QNetworkAccessManager* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QObject, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QNetworkAccessManager, &sipRes);

    return sipRes;
}

void sipVH_QtQml_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

void sipVH_QtQml_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QObject, SIP_NULLPTR);
}

void sipVH_QtQml_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QQmlIncubator::Status a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QQmlIncubator_Status);
}

void sipVH_QtQml_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QQmlEngine*a0, const char*a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DA", a0, sipType_QQmlEngine, SIP_NULLPTR, a1);
}

void sipVH_QtQml_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "A", a0);
}

::QQmlImageProviderBase::Flags sipVH_QtQml_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QQmlImageProviderBase::Flags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100QQmlImageProviderBase_Flag, &sipRes);

    return sipRes;
}

::QQmlImageProviderBase::ImageType sipVH_QtQml_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QQmlImageProviderBase::ImageType sipRes = ::QQmlImageProviderBase::Image;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QQmlImageProviderBase_ImageType, &sipRes);

    return sipRes;
}

void sipVH_QtQml_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

::QObject* sipVH_QtQml_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QQmlContext*a0)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QQmlContext, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QObject, &sipRes);

    return sipRes;
}

::QUrl sipVH_QtQml_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0, ::QQmlAbstractUrlInterceptor::DataType a1)
{
    ::QUrl sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR, a1, sipType_QQmlAbstractUrlInterceptor_DataType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QUrl, &sipRes);

    return sipRes;
}

bool sipVH_QtQml_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtQml_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtQml_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtQml_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtQml_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtQml_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


PyDoc_STRVAR(doc_qmlRegisterUncreatableType, "qmlRegisterUncreatableType(a0: type, uri: str, major: int, minor: int, reason: str|None, qmlName: str = None) -> int");

extern "C" {static PyObject *func_qmlRegisterUncreatableType(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qmlRegisterUncreatableType(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        const ::QString* a4;
        int a4State = 0;
        const char* a5 = 0;
        PyObject *a5Keep = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_qmlName,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "TAAiiJ1|AA", &PyType_Type, &a0, &a1Keep, &a1, &a2, &a3, sipType_QString, &a4, &a4State, &a5Keep, &a5))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 80 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
    if ((sipRes = qpyqml_register_uncreatable_type((PyTypeObject *)a0, a1, a2, a3, a5, *a4)) < 0)
        sipError = sipErrorFail;
#line 702 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
            Py_DECREF(a1Keep);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);
            Py_XDECREF(a5Keep);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return PyLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterUncreatableType, doc_qmlRegisterUncreatableType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterAnonymousType, "qmlRegisterAnonymousType(a0: type, uri: str, major: int) -> int");

extern "C" {static PyObject *func_qmlRegisterAnonymousType(PyObject *, PyObject *);}
static PyObject *func_qmlRegisterAnonymousType(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "TAAi", &PyType_Type, &a0, &a1Keep, &a1, &a2))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 72 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
    if ((sipRes = qpyqml_register_anonymous_type((PyTypeObject *)a0, a1, a2)) < 0)
        sipError = sipErrorFail;
#line 747 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
            Py_DECREF(a1Keep);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return PyLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterAnonymousType, doc_qmlRegisterAnonymousType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterSingletonInstance, "qmlRegisterSingletonInstance(uri: str, major: int, minor: int, typeName: str, cppObject: QObject|None) -> int");

extern "C" {static PyObject *func_qmlRegisterSingletonInstance(PyObject *, PyObject *);}
static PyObject *func_qmlRegisterSingletonInstance(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        int a1;
        int a2;
        const char* a3;
        PyObject *a3Keep;
        ::QObject* a4;

        if (sipParseArgs(&sipParseErr, sipArgs, "AAiiAAJ8", &a0Keep, &a0, &a1, &a2, &a3Keep, &a3, sipType_QObject, &a4))
        {
            int sipRes;

            sipRes = qmlRegisterSingletonInstance(a0, a1, a2, a3, a4);
            Py_DECREF(a0Keep);
            Py_DECREF(a3Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterSingletonInstance, doc_qmlRegisterSingletonInstance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterRevision, "qmlRegisterRevision(a0: type, uri: str, major: int, minor: int, attachedProperties: type = None) -> int");

extern "C" {static PyObject *func_qmlRegisterRevision(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qmlRegisterRevision(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        PyObject * a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_attachedProperties,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "TAAii|T", &PyType_Type, &a0, &a1Keep, &a1, &a2, &a3, &PyType_Type, &a4))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
    if ((sipRes = qpyqml_register_library_type((PyTypeObject *)a0, a1, a2, a3, nullptr, (PyTypeObject *)a4)) < 0)
        sipError = sipErrorFail;
#line 835 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
            Py_DECREF(a1Keep);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return PyLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterRevision, doc_qmlRegisterRevision);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlAttachedPropertiesObject, "qmlAttachedPropertiesObject(a0: type, object: QObject|None, create: bool = True) -> QObject|None");

extern "C" {static PyObject *func_qmlAttachedPropertiesObject(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qmlAttachedPropertiesObject(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QObject* a1;
        bool a2 = 1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_create,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "TJ8|b", &PyType_Type, &a0, sipType_QObject, &a1, &a2))
        {
            ::QObject*sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 29 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlattachedpropertiesobject.sip"
    QObject *proxy = qpyqml_find_proxy_for(a1);

    if (!proxy)
    {
        sipError = sipErrorFail;
    }
    else
    {
        const QMetaObject *mo = pyqt6_qtqml_get_qmetaobject((PyTypeObject *)a0);

        sipRes = qmlAttachedPropertiesObject(proxy,
                qmlAttachedPropertiesFunction(nullptr, mo), a2);
    }
#line 894 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlAttachedPropertiesObject, doc_qmlAttachedPropertiesObject);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot___rshift__(PyObject *, PyObject *);}
static PyObject *slot___rshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDataStream* a0;
        ::QJSValue* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QJSValue, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot___lshift__(PyObject *, PyObject *);}
static PyObject *slot___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDataStream* a0;
        const ::QJSValue* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QJSValue, &a1, &a1State))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QJSValue *>(a1), sipType_QJSValue, a1State);

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


PyDoc_STRVAR(doc_qjsEngine, "qjsEngine(a0: QObject|None) -> QJSEngine|None");

extern "C" {static PyObject *func_qjsEngine(PyObject *, PyObject *);}
static PyObject *func_qjsEngine(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QObject, &a0))
        {
            ::QJSEngine*sipRes;

            sipRes = qjsEngine(a0);

            return sipConvertFromType(sipRes, sipType_QJSEngine, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qjsEngine, doc_qjsEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlEngine, "qmlEngine(a0: QObject|None) -> QQmlEngine|None");

extern "C" {static PyObject *func_qmlEngine(PyObject *, PyObject *);}
static PyObject *func_qmlEngine(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QObject, &a0))
        {
            ::QQmlEngine*sipRes;

            sipRes = qmlEngine(a0);

            return sipConvertFromType(sipRes, sipType_QQmlEngine, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlEngine, doc_qmlEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlContext, "qmlContext(a0: QObject|None) -> QQmlContext|None");

extern "C" {static PyObject *func_qmlContext(PyObject *, PyObject *);}
static PyObject *func_qmlContext(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QObject, &a0))
        {
            ::QQmlContext*sipRes;

            sipRes = qmlContext(a0);

            return sipConvertFromType(sipRes, sipType_QQmlContext, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlContext, doc_qmlContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlTypeId, "qmlTypeId(uri: str, versionMajor: int, versionMinor: int, qmlName: str) -> int");

extern "C" {static PyObject *func_qmlTypeId(PyObject *, PyObject *);}
static PyObject *func_qmlTypeId(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        int a1;
        int a2;
        const char* a3;
        PyObject *a3Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "AAiiAA", &a0Keep, &a0, &a1, &a2, &a3Keep, &a3))
        {
            int sipRes;

            sipRes = qmlTypeId(a0, a1, a2, a3);
            Py_DECREF(a0Keep);
            Py_DECREF(a3Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlTypeId, doc_qmlTypeId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterType, "qmlRegisterType(url: QUrl, uri: str, versionMajor: int, versionMinor: int, qmlName: str) -> int\n"
"qmlRegisterType(a0: type, uri: str, major: int, minor: int, name: str = None, attachedProperties: type = None) -> int");

extern "C" {static PyObject *func_qmlRegisterType(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qmlRegisterType(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        const char* a4;
        PyObject *a4Keep;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "J9AAiiAA", sipType_QUrl, &a0, &a1Keep, &a1, &a2, &a3, &a4Keep, &a4))
        {
            int sipRes;

            sipRes = qmlRegisterType(*a0, a1, a2, a3, a4);
            Py_DECREF(a1Keep);
            Py_DECREF(a4Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    {
        PyObject * a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        const char* a4 = 0;
        PyObject *a4Keep = 0;
        PyObject * a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_name,
            sipName_attachedProperties,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "TAAii|AAT", &PyType_Type, &a0, &a1Keep, &a1, &a2, &a3, &a4Keep, &a4, &PyType_Type, &a5))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 65 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
    if ((sipRes = qpyqml_register_library_type((PyTypeObject *)a0, a1, a2, a3, a4, (PyTypeObject *)a5)) < 0)
        sipError = sipErrorFail;
#line 1154 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
            Py_DECREF(a1Keep);
            Py_XDECREF(a4Keep);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return PyLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterType, doc_qmlRegisterType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterSingletonType, "qmlRegisterSingletonType(url: QUrl, uri: str, versionMajor: int, versionMinor: int, qmlName: str) -> int\n"
"qmlRegisterSingletonType(a0: type, uri: str, major: int, minor: int, factory: Callable[[QQmlEngine, QJSEngine], Any], name: str = None) -> int");

extern "C" {static PyObject *func_qmlRegisterSingletonType(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qmlRegisterSingletonType(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        const char* a4;
        PyObject *a4Keep;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "J9AAiiAA", sipType_QUrl, &a0, &a1Keep, &a1, &a2, &a3, &a4Keep, &a4))
        {
            int sipRes;

            sipRes = qmlRegisterSingletonType(*a0, a1, a2, a3, a4);
            Py_DECREF(a1Keep);
            Py_DECREF(a4Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    {
        PyObject * a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        PyObject * a4;
        const char* a5 = 0;
        PyObject *a5Keep = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_name,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "TAAiiF|AA", &PyType_Type, &a0, &a1Keep, &a1, &a2, &a3, &a4, &a5Keep, &a5))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 57 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
    if ((sipRes = qpyqml_register_singleton_type((PyTypeObject *)a0, a1, a2, a3, a5, a4)) < 0)
        sipError = sipErrorFail;
#line 1233 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"
            Py_DECREF(a1Keep);
            Py_XDECREF(a5Keep);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return PyLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterSingletonType, doc_qmlRegisterSingletonType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterModule, "qmlRegisterModule(uri: str, versionMajor: int, versionMinor: int)");

extern "C" {static PyObject *func_qmlRegisterModule(PyObject *, PyObject *);}
static PyObject *func_qmlRegisterModule(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "AAii", &a0Keep, &a0, &a1, &a2))
        {
            qmlRegisterModule(a0, a1, a2);
            Py_DECREF(a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterModule, doc_qmlRegisterModule);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlProtectModule, "qmlProtectModule(uri: str, majVersion: int) -> bool");

extern "C" {static PyObject *func_qmlProtectModule(PyObject *, PyObject *);}
static PyObject *func_qmlProtectModule(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        int a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "AAi", &a0Keep, &a0, &a1))
        {
            bool sipRes;

            sipRes = qmlProtectModule(a0, a1);
            Py_DECREF(a0Keep);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlProtectModule, doc_qmlProtectModule);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterUncreatableMetaObject, "qmlRegisterUncreatableMetaObject(staticMetaObject: QMetaObject, uri: str, versionMajor: int, versionMinor: int, qmlName: str, reason: str|None) -> int");

extern "C" {static PyObject *func_qmlRegisterUncreatableMetaObject(PyObject *, PyObject *);}
static PyObject *func_qmlRegisterUncreatableMetaObject(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaObject* a0;
        const char* a1;
        PyObject *a1Keep;
        int a2;
        int a3;
        const char* a4;
        PyObject *a4Keep;
        const ::QString* a5;
        int a5State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9AAiiAAJ1", sipType_QMetaObject, &a0, &a1Keep, &a1, &a2, &a3, &a4Keep, &a4, sipType_QString, &a5, &a5State))
        {
            int sipRes;

            sipRes = qmlRegisterUncreatableMetaObject(*a0, a1, a2, a3, a4, *a5);
            Py_DECREF(a1Keep);
            Py_DECREF(a4Keep);
            sipReleaseType(const_cast< ::QString *>(a5), sipType_QString, a5State);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterUncreatableMetaObject, doc_qmlRegisterUncreatableMetaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlRegisterTypeNotAvailable, "qmlRegisterTypeNotAvailable(uri: str, versionMajor: int, versionMinor: int, qmlName: str, message: str|None) -> int");

extern "C" {static PyObject *func_qmlRegisterTypeNotAvailable(PyObject *, PyObject *);}
static PyObject *func_qmlRegisterTypeNotAvailable(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        int a1;
        int a2;
        const char* a3;
        PyObject *a3Keep;
        const ::QString* a4;
        int a4State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "AAiiAAJ1", &a0Keep, &a0, &a1, &a2, &a3Keep, &a3, sipType_QString, &a4, &a4State))
        {
            int sipRes;

            sipRes = qmlRegisterTypeNotAvailable(a0, a1, a2, a3, *a4);
            Py_DECREF(a0Keep);
            Py_DECREF(a3Keep);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlRegisterTypeNotAvailable, doc_qmlRegisterTypeNotAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qmlClearTypeRegistrations, "qmlClearTypeRegistrations()");

extern "C" {static PyObject *func_qmlClearTypeRegistrations(PyObject *, PyObject *);}
static PyObject *func_qmlClearTypeRegistrations(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            qmlClearTypeRegistrations();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qmlClearTypeRegistrations, doc_qmlClearTypeRegistrations);

    return SIP_NULLPTR;
}

static sipPySlotExtenderDef slotExtenders[] = {
    {(void *)slot___rshift__, rshift_slot, {0, 0, 0}},
    {(void *)slot___lshift__, lshift_slot, {0, 0, 0}},
    {SIP_NULLPTR, (sipPySlotType)0, {0, 0, 0}}
};


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QJSEngine(void **);}
static const sipTypeDef *sipSubClass_QJSEngine(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 34 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsengine.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QJSEngine, &sipType_QJSEngine, 9, 1},
        {sipName_QQmlComponent, &sipType_QQmlComponent, -1, 2},
        {sipName_QQmlContext, &sipType_QQmlContext, -1, 3},
        {sipName_QQmlEngineExtensionPlugin, &sipType_QQmlEngineExtensionPlugin, -1, 4},
        {sipName_QQmlExpression, &sipType_QQmlExpression, -1, 5},
        {sipName_QQmlExtensionPlugin, &sipType_QQmlExtensionPlugin, -1, 6},
        {sipName_QQmlFileSelector, &sipType_QQmlFileSelector, -1, 7},
        {sipName_QQmlImageProviderBase, &sipType_QQmlImageProviderBase, -1, 8},
        {sipName_QQmlPropertyMap, &sipType_QQmlPropertyMap, -1, -1},
        {sipName_QQmlEngine, &sipType_QQmlEngine, 10, -1},
        {sipName_QQmlApplicationEngine, &sipType_QQmlApplicationEngine, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1464 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSEngine__Extension, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Extension, 2, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSEngine__ObjectOwnership, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ObjectOwnership, 2, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSManagedValue__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 5, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSPrimitiveValue__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 9, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSValue__ErrorType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ErrorType, 11, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSValue__ObjectConversionBehavior, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ObjectConversionBehavior, 11, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QJSValue__SpecialValue, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SpecialValue, 11, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlAbstractUrlInterceptor__DataType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_DataType, 22, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlComponent__CompilationMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CompilationMode, 25, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlComponent__Status, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Status, 25, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlImageProviderBase__Flag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Flag, 36, 1, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlImageProviderBase__ImageType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ImageType, 36, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlIncubator__IncubationMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_IncubationMode, 40, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlIncubator__Status, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Status, 40, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlProperty__PropertyTypeCategory, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_PropertyTypeCategory, 47, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QQmlProperty__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 47, 3, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtQml[] = {
    &sipTypeDef_QtQml_QFlags_0100QJSEngine_Extension.mtd_base,
    &sipTypeDef_QtQml_QFlags_0100QQmlImageProviderBase_Flag.mtd_base,
    &sipTypeDef_QtQml_QJSEngine.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtQml_QJSManagedValue.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtQml_QJSPrimitiveNull.ctd_base,
    &sipTypeDef_QtQml_QJSPrimitiveUndefined.ctd_base,
    &sipTypeDef_QtQml_QJSPrimitiveValue.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtQml_QJSValue.ctd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtQml_QJSValueIterator.ctd_base,
    &sipTypeDef_QtQml_QList_0100QJSValue.mtd_base,
    &sipTypeDef_QtQml_QList_0101QQmlAbstractUrlInterceptor.mtd_base,
    &sipTypeDef_QtQml_QList_0101QQmlContext.mtd_base,
    &sipTypeDef_QtQml_QList_0100QQmlContext_PropertyPair.mtd_base,
    &sipTypeDef_QtQml_QList_0100QQmlError.mtd_base,
    &sipTypeDef_QtQml_QList_0100QQmlProperty.mtd_base,
    &sipTypeDef_QtQml_QQmlAbstractUrlInterceptor.ctd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtQml_QQmlApplicationEngine.ctd_base,
    &sipTypeDef_QtQml_QQmlComponent.ctd_base,
    &enumTypes[8].etd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtQml_QQmlContext.ctd_base,
    &sipTypeDef_QtQml_QQmlContext_PropertyPair.ctd_base,
    &sipTypeDef_QtQml_QQmlEngine.ctd_base,
    &sipTypeDef_QtQml_QQmlEngineExtensionPlugin.ctd_base,
    &sipTypeDef_QtQml_QQmlError.ctd_base,
    &sipTypeDef_QtQml_QQmlExpression.ctd_base,
    &sipTypeDef_QtQml_QQmlExtensionPlugin.ctd_base,
    &sipTypeDef_QtQml_QQmlFileSelector.ctd_base,
    &sipTypeDef_QtQml_QQmlImageProviderBase.ctd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtQml_QQmlIncubationController.ctd_base,
    &sipTypeDef_QtQml_QQmlIncubator.ctd_base,
    &enumTypes[12].etd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtQml_QQmlListProperty_0100QObject.mtd_base,
    &sipTypeDef_QtQml_QQmlListReference.ctd_base,
    &sipTypeDef_QtQml_QQmlNetworkAccessManagerFactory.ctd_base,
    &sipTypeDef_QtQml_QQmlParserStatus.ctd_base,
    &sipTypeDef_QtQml_QQmlProperty.ctd_base,
    &enumTypes[14].etd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_QtQml_QQmlPropertyMap.ctd_base,
    &sipTypeDef_QtQml_QQmlPropertyValueSource.ctd_base,
    &sipTypeDef_QtQml_QQmlScriptString.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QJSEngine::Extensions", "QFlags<QJSEngine::Extension>"},
    {"QJSValueList", "QList<QJSValue>"},
    {"QQmlImageProviderBase::Flags", "QFlags<QQmlImageProviderBase::Flag>"},
    {"QQmlProperties", "QList<QQmlProperty>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtQml_QtCore[] = {
    {"QAnyStringView"},
    {"QByteArray"},
    {"QChildEvent"},
    {"QDataStream"},
    {"QDateTime"},
    {"QEvent"},
    {"QFileSelector"},
    {"QHash<QString,QVariant>"},
    {"QList<QObject*>"},
    {"QMap<QString,QVariant>"},
    {"QMetaMethod"},
    {"QMetaObject"},
    {"QMetaProperty"},
    {"QMetaType"},
    {"QObject"},
    {"QRegularExpression"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QtMsgType"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQml_QtCore[] = {
    {"PyQt6"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtNetwork. */
sipImportedTypeDef sipImportedTypes_QtQml_QtNetwork[] = {
    {"QNetworkAccessManager"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt6.QtCore", sipImportedTypes_QtQml_QtCore, sipImportedVirtErrorHandlers_QtQml_QtCore, SIP_NULLPTR},
    {"PyQt6.QtNetwork", sipImportedTypes_QtQml_QtNetwork, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QJSEngine, {14, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtQml = {
    SIP_NULLPTR,
    8,
    sipNameNr_PyQt6_QtQml,
    0,
    sipStrings_QtQml,
    importsTable,
    53,
    sipExportedTypes_QtQml,
    SIP_NULLPTR,
    4,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    slotExtenders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtQml;

sip_qt_metaobject_func sip_QtQml_qt_metaobject;
sip_qt_metacall_func sip_QtQml_qt_metacall;
sip_qt_metacast_func sip_QtQml_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtQml()
#else
PyMODINIT_FUNC PyInit_QtQml()
#endif
{
    static PyMethodDef sip_methods[] = {
        {sipName_qmlRegisterUncreatableType, SIP_MLMETH_CAST(func_qmlRegisterUncreatableType), METH_VARARGS|METH_KEYWORDS, doc_qmlRegisterUncreatableType},
        {sipName_qmlRegisterAnonymousType, func_qmlRegisterAnonymousType, METH_VARARGS, doc_qmlRegisterAnonymousType},
        {sipName_qmlRegisterSingletonInstance, func_qmlRegisterSingletonInstance, METH_VARARGS, doc_qmlRegisterSingletonInstance},
        {sipName_qmlRegisterRevision, SIP_MLMETH_CAST(func_qmlRegisterRevision), METH_VARARGS|METH_KEYWORDS, doc_qmlRegisterRevision},
        {sipName_qmlAttachedPropertiesObject, SIP_MLMETH_CAST(func_qmlAttachedPropertiesObject), METH_VARARGS|METH_KEYWORDS, doc_qmlAttachedPropertiesObject},
        {sipName_qjsEngine, func_qjsEngine, METH_VARARGS, doc_qjsEngine},
        {sipName_qmlEngine, func_qmlEngine, METH_VARARGS, doc_qmlEngine},
        {sipName_qmlContext, func_qmlContext, METH_VARARGS, doc_qmlContext},
        {sipName_qmlTypeId, func_qmlTypeId, METH_VARARGS, doc_qmlTypeId},
        {sipName_qmlRegisterType, SIP_MLMETH_CAST(func_qmlRegisterType), METH_VARARGS|METH_KEYWORDS, doc_qmlRegisterType},
        {sipName_qmlRegisterSingletonType, SIP_MLMETH_CAST(func_qmlRegisterSingletonType), METH_VARARGS|METH_KEYWORDS, doc_qmlRegisterSingletonType},
        {sipName_qmlRegisterModule, func_qmlRegisterModule, METH_VARARGS, doc_qmlRegisterModule},
        {sipName_qmlProtectModule, func_qmlProtectModule, METH_VARARGS, doc_qmlProtectModule},
        {sipName_qmlRegisterUncreatableMetaObject, func_qmlRegisterUncreatableMetaObject, METH_VARARGS, doc_qmlRegisterUncreatableMetaObject},
        {sipName_qmlRegisterTypeNotAvailable, func_qmlRegisterTypeNotAvailable, METH_VARARGS, doc_qmlRegisterTypeNotAvailable},
        {sipName_qmlClearTypeRegistrations, func_qmlClearTypeRegistrations, METH_VARARGS, doc_qmlClearTypeRegistrations},
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt6.QtQml",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt6.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt6.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtQml = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt6.sip._C_API"));

    if (sipAPI_QtQml == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtQml, 13, 8, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtQml_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtQml_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtQml_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtQml_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtQml, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
    qMetaTypeId<::QQmlProperty::Type>();
    qMetaTypeId<::QQmlProperty::PropertyTypeCategory>();
    qMetaTypeId<::QQmlIncubator::Status>();
    qMetaTypeId<::QQmlIncubator::IncubationMode>();
    qMetaTypeId<::QQmlImageProviderBase::Flag>();
    qMetaTypeId<::QQmlImageProviderBase::ImageType>();
    qMetaTypeId<::QQmlComponent::Status>();
    qMetaTypeId<::QQmlComponent::CompilationMode>();
    qMetaTypeId<::QQmlAbstractUrlInterceptor::DataType>();
    qMetaTypeId<::QJSValue::ErrorType>();
    qMetaTypeId<::QJSValue::ObjectConversionBehavior>();
    qMetaTypeId<::QJSValue::SpecialValue>();
    qMetaTypeId<::QJSPrimitiveValue::Type>();
    qMetaTypeId<::QJSManagedValue::Type>();
    qMetaTypeId<::QJSEngine::ObjectOwnership>();
    qMetaTypeId<::QJSEngine::Extension>();
    qMetaTypeId<QFlags< ::QQmlImageProviderBase::Flag>>();
    qMetaTypeId<QFlags< ::QJSEngine::Extension>>();
#line 207 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsengine.sip"
qpyqml_post_init(sipModuleDict);
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlproperty.sip"
// Imports from QtCore.
pyqt6_qtqml_get_connection_parts = (pyqt6_qtqml_get_connection_parts_t)sipImportSymbol("pyqt6_get_connection_parts");
Q_ASSERT(pyqt6_qtqml_get_connection_parts);
#line 34 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
// Imports from QtCore.
pyqt6_qtqml_get_qmetaobject = (pyqt6_qtqml_get_qmetaobject_t)sipImportSymbol(
        "pyqt6_get_qmetaobject");
Q_ASSERT(pyqt6_qtqml_get_qmetaobject);
#line 1775 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlcmodule.cpp"

    return sipModule;
}
